﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Prohlizec
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            m_selected = null;
        }

        private preview m_selected;
        private String m_lastDir;

        private void ScanTree(String path, TreeNode parent)
        {
            if (path[path.Length - 1] == '\\' || path[path.Length - 1] == '\\') path = path.Substring(0, path.Length - 1);

            // get directory name
            String dirname = System.IO.Path.GetFileNameWithoutExtension(path);
            if (dirname == "") dirname = path;

            TreeNode tn;
            if (parent == null)
                tn = tree.Nodes.Add(dirname);
            else
                tn = parent.Nodes.Add(dirname);

            tn.Tag = path;

            String[] dirs = System.IO.Directory.GetDirectories(path);
            foreach (String d in dirs)
            {
                ScanTree(d, tn);
            }
        }

        private void ListDir(String path)
        {
            this.Text = "Prohlížeč obrázků - Prosím čekejte...";
            this.Cursor = Cursors.WaitCursor;

            int lastX = 5; int lastY = 5;
            if (m_lastDir == path)
            {
                // only re-arrange
                //preview[] cc = new preview[];
                Array cc = Array.CreateInstance(typeof(preview), this.cont.Panel2.Controls.Count);
                this.cont.Panel2.Controls.CopyTo(cc,0);
                this.cont.Panel2.Controls.Clear();

                foreach (preview pr in cc)
                {
                    // set new position
                    pr.Left = lastX; pr.Top = lastY;

                    this.cont.Panel2.Controls.Add(pr); // add to panel

                    lastX += pr.Width + 10;

                    if (lastX + pr.Width > this.cont.Panel2.Width)
                    {
                        lastX = 5;
                        lastY += pr.Height + 10;
                    }
                }
                this.Cursor = Cursors.Default;
                this.Text = "Prohlížeč obrázků";
                return;
            }

            m_lastDir = path;

            // remove all previous thumbnails
            this.cont.Panel2.Controls.Clear();

            String[] files = System.IO.Directory.GetFiles(path, "*.jp*g");

            foreach (String f in files)
            {
                preview pr = new preview(); // new preview component
                pr.Visible = false;

                // set click event
                pr.PreviewClick += new System.EventHandler(this.preview_Click);
                pr.GotFocus += new System.EventHandler(this.preview_Focus);
                pr.PreviewSelect += new System.EventHandler(this.preview_Select);

                // laod image
                pr.LoadImage(f);

                // set position and add to panel
                pr.Left = lastX; pr.Top = lastY;
                this.cont.Panel2.Controls.Add(pr);

                lastX += pr.Width + 10;

                if (lastX + pr.Width > this.cont.Panel2.Width)
                {
                    lastX = 5;
                    lastY += pr.Height + 10;
                }

            }

            // visible to true
            foreach (preview pr in this.cont.Panel2.Controls)
            {
                pr.Visible = true;
            }

            this.Cursor = Cursors.Default;
            this.Text = "Prohlížeč obrázků";
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            String startPath = Application.StartupPath;


            String[] cmdl = Environment.GetCommandLineArgs();

            if (cmdl.Length >= 2)
            {
                startPath = cmdl[1];
            }

            // DOCASNE
            //startPath = "C:\\Data k testovani";

            // fed tree with directory content
            ScanTree(startPath, null);
            tree.ExpandAll();

            // show preview images
            ListDir(startPath);
        }

        private void preview_Focus(object sender, EventArgs e)
        {
            // deselect all
            foreach (preview p in this.cont.Panel2.Controls)
                p.Select(false);

            // select thumbnail
            preview pr = (preview)sender;
            pr.Select(true);

            m_selected = pr;
        }

        private void preview_Select(object sender, EventArgs e)
        {
            full f = new full();

            f.Show(); // necessary?

            Array cc = Array.CreateInstance(typeof(preview), this.cont.Panel2.Controls.Count);
            this.cont.Panel2.Controls.CopyTo(cc, 0);

            f.ShowFullscreen(cc, m_selected);

            //f.ShowDialog();

        }

        private void preview_Click(object sender, EventArgs e)
        {
            // set focus
            preview pr = (preview)sender;
            pr.Focus();
        }

        private void cont_Panel2_MouseClick(object sender, MouseEventArgs e)
        {
            // set focus to comonent
            if (m_selected != null)
                m_selected.Focus();
            else
            {
                if (this.cont.Panel2.Controls.Count > 0)
                    this.cont.Panel2.Controls[0].Focus();
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void cont_Panel2_Resize(object sender, EventArgs e)
        {
            //System.Threading.Thread.Sleep(2000);
            if (m_lastDir!=null)
                ListDir(m_lastDir);
        }

        private void tree_AfterSelect(object sender, TreeViewEventArgs e)
        {
            if (tree.SelectedNode == null) return;
            String path = (String)tree.SelectedNode.Tag;
            ListDir(path);
        }

    }
}
