﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Prohlizec
{
    public partial class preview : UserControl
    {
        public preview()
        {
            InitializeComponent();
            m_path = null;
            m_date = null;
            m_desc = null;
        }

        public EventHandler PreviewClick;
        public EventHandler PreviewSelect;

        private String m_path;
        private String m_desc;
        private String m_date;

        public bool LoadImage(String path)
        {
            m_path = path;

            // load image from file
            Image img = Image.FromFile(path);
            if (img==null) return false;

            // Get file name
            lblName.Text = System.IO.Path.GetFileName(path);

            // Generate thumbnail and retain aspect ratio
            if (img.Width>img.Height)
                pic.Image = img.GetThumbnailImage(pic.Width, (int)(img.Height*((float)pic.Width/img.Width)), null, System.IntPtr.Zero);
            else
                pic.Image = img.GetThumbnailImage((int)(img.Width * ((float)pic.Height / img.Height)), pic.Height, null, System.IntPtr.Zero);

            // retrieve creation date and time
            lblDate.Text = System.IO.File.GetLastWriteTime(path).ToShortDateString() + " " + System.IO.File.GetLastWriteTime(path).ToLongTimeString();
            m_date = lblDate.Text;

            // get resolution and file size
            System.IO.FileInfo fileInfo = new System.IO.FileInfo(path);
            
            // format size string
            String lenString;
            if (fileInfo.Length < 1024)
                lenString = fileInfo.Length + " B";
            else if (fileInfo.Length < 1024*1024)
                lenString = fileInfo.Length/1024 + " kB";
            else //if (fileInfo.Length < 1024 * 1024 * 1024)
                lenString = fileInfo.Length / (1024 * 1024) + " MB";

            lblDesc.Text = img.Width + "x" + img.Height + " " + lenString;
            m_desc = lblDesc.Text;

            return true;
        }

        public void Select(bool bSelect)
        {
            if (bSelect)
            {
                lblDate.BackColor = lblDesc.BackColor = lblName.BackColor = Color.Blue;
                lblDate.ForeColor = lblDesc.ForeColor = lblName.ForeColor = Color.White;
            }
            else
            {
                lblDate.BackColor = lblDesc.BackColor = lblName.BackColor = Color.Transparent;
                lblDate.ForeColor = lblDesc.ForeColor = lblName.ForeColor = Color.Black;
            }
        }

        private void pic_Click(object sender, EventArgs e)
        {
             PreviewClick.Invoke(this, e);
        }

        private void lblDate_Click(object sender, EventArgs e)
        {
            PreviewClick.Invoke(this, e);
        }

        private void PrevSelectEvent(object sender, EventArgs e)
        {
            PreviewSelect.Invoke(this, e);
        }

        public String GetPath()
        {
            return m_path;
        }
        public String GetDate()
        {
            return m_date;
        }
        public String GetDesc()
        {
            return m_desc;
        }

    }
}
